[**Options avancées**](./introduction.md) > **Code de langue** _(actuel)_

---

#### Google

Source <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organisé par GPT-4o.

| Libellé en chinois | Libellé | `Language Code` |
| --- | --- | --- |
| Amharique | Amharic | `am` |
| Arabe | Arabic | `ar` |
| 白俄罗斯语 | Belarusian | `be` |
|---|---|---|---|---|---|---|
| 孟加拉语 | Bengali | `bn` |
### Traduction en français :

| Bengali | Bengali | `bn` |
| Français (France) | French (France) | `fr-FR` |
| Portugais (Brésil) | Portuguese (Brazil) | `pt-BR` |
| Bulgare | Bulgarian | `bg` |
| Catalan | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croate | Croatian | `hr` |
| Tchèque | Czech | `cs` |
| Danois | Danish | `da` |
| Néerlandais | Dutch | `nl` |
| Français (France) | French (FR) | `fr` |
| 法语 | French | `fr` |
|---|---|---|---|---|---|
| 芬兰语 | Finnish | `fi` | 德语 | German | `de` |
| 希腊语 | Greek | `el` | 印地语 | Hindi | `hi` |
| 匈牙利语 | Hungarian | `hu` | 意大利语 | Italian | `it` |
| 日语 | Japanese | `ja` | 韩语 | Korean | `ko` |
| 拉脱维亚语 | Latvian | `lv` | 立陶宛语 | Lithuanian | `lt` |
| 挪威语 | Norwegian | `no` | 波兰语 | Polish | `pl` |
| 葡萄牙语 | Portuguese | `pt` | 罗马尼亚语 | Romanian | `ro` |
| 俄语 | Russian | `ru` | 斯洛伐克语 | Slovak | `sk` |
| 斯洛文尼亚语 | Slovenian | `sl` | 西班牙语 | Spanish | `es` |
| 瑞典语 | Swedish | `sv` | 泰语 | Thai | `th` |
| 土耳其语 | Turkish | `tr` | 乌克兰语 | Ukrainian | `uk` |
| 越南语 | Vietnamese | `vi` | 中文 | Chinese | `zh` |

### Translation:

| Estonien | Estonian | `et` | Français | French | `fr` |
|---|---|---|---|---|---|
| Finnois | Finnish | `fi` | Allemand | German | `de` |
| Grec | Greek | `el` | Hindi | Hindi | `hi` |
| Hongrois | Hungarian | `hu` | Italien | Italian | `it` |
| Japonais | Japanese | `ja` | Coréen | Korean | `ko` |
| Letton | Latvian | `lv` | Lituanien | Lithuanian | `lt` |
| Norvégien | Norwegian | `no` | Polonais | Polish | `pl` |
| Portugais | Portuguese | `pt` | Roumain | Romanian | `ro` |
| Russe | Russian | `ru` | Slovaque | Slovak | `sk` |
| Slovène | Slovenian | `sl` | Espagnol | Spanish | `es` |
| Suédois | Swedish | `sv` | Thaï | Thai | `th` |
| Turc | Turkish | `tr` | Ukrainien | Ukrainian | `uk` |
| Vietnamien | Vietnamese | `vi` | Chinois | Chinese | `zh` |
| 菲律宾语 | Filipino | `fil` |
| Finnois | Finnish | `fi` |
| Français | French | `fr` |
| 德语 | Allemand | `de` |
| Grec | `el` |
| Gujarati | Gujarati | `gu` |
| Hébreu | Hebrew | `iw` |
| Hindi | Hindi | `hi` |
| Hongrois | Hungarian | `hu` |
| Islandais | `is` |
| Indonésien | Indonesian | `id` |
| Italien | Italian | `it` |
| Japonais | `ja` |
| Kannada | Kannada | `kn` |
| 韩语 | Coréen | `ko` |
| 拉脱维亚语 | Letton | `lv` |
| Lituanien | Lithuanian | `lt` |
| Malais | Malay | `ms` |
| Malayalam | Malayalam | `ml` |
| Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| Polonais | `pl` |
| Portugais (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Roumain | Romanian | `ro` |
| Russe | Russian | `ru` |
| Serbe | Serbian | `sr` |
| Français (France) | French (France) | `fr-FR` |
| Slovaque | Slovak | `sk` |
| Slovène | Slovenian | `sl` |
| Espagnol | Spanish | `es` |
| Swahili | Swahili | `sw` |
| Suédois | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| Thaï | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| Turc | Turkish | `tr` |
| Urdu | `ur` |
| Ukrainien | Ukrainian | `uk` |
|  Vietnamien | Vietnamese | `vi` |
| Gallois | Welsh | `cy` |

#### DeepL

Source <https://developers.deepl.com/docs/resources/supported-languages>, organisé par GPT-4o.

| Libellé en chinois | Libellé | `Language Code` | Supports |
| --- | --- | --- | --- |
| Arabe | Arabic | `AR` | `source`, `target` |
| Bulgare | Bulgarian | `BG` | `source`, `target` |
| Tchèque | Czech | `CS` | `source`, `target` |
| Danois | Danish | `DA` | `source`, `target` |
| Allemand | `DE` | `source`, `target` |
| Grec | `EL` | `source`, `target` |
| 法语 | French | `FR` | `source`, `target` |
|------|---------|------|--------------------|--------|------|--------|------|--------------------|
| 英语 | English | `EN` | `source`, `target` | 法语 | French | `FR` | `source`, `target` |
| 英语（英国） | English (British) | `EN-GB` | `target` |
| 英语（美国） | English (American) | `EN-US` | `target` |
| Espagnol | Spanish | `ES` | `source`, `target` |
| Estonien | Estonian | `ET` | `source`, `target` |
| Finnois | Finnish | `FI` | `source`, `target` |
|  Français  |  French  |  `FR`  |  `source`, `target`  |
| Hongrois | Hungarian | `HU` | `source`, `target` |
| 印尼语 | Indonesian | `ID` | `source`, `target` |
| Italien | Italian | `IT` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| Coréen | Korean | `KO` | `source`, `target` |
| Lituanien | Lithuanian | `LT` | `source`, `target` |
| Letton | Latvian | `LV` | `source`, `target` |
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
| Néerlandais | Dutch | `NL` | `source`, `target` |
| Polonais | Polish | `PL` | `source`, `target` |
| Portugais | Portuguese | `PT` | `source`, `target` |
| Portugais (Brésil) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portugais (Europe) | Portuguese (European) | `PT-PT` | `target` |
| Roumain | Romanian | `RO` | `source`, `target` |
| Russe | Russian | `RU` | `source`, `target` |
| Slovaque | Slovak | `SK` | `source`, `target` |
| Slovène | Slovenian | `SL` | `source`, `target` |
| Suédois | Swedish | `SV` | `source`, `target` |
| Turc | Turkish | `TR` | `source`, `target` |
|  Ukrainien | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinois | `ZH` | `source`, `target` |
| Français | French | `FR` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>